==> zio-aws-honeycode_3-5.17.104.1-sources.jar: zio/aws/honeycode/model/BatchCreateTableRowsResponse.scala <==
package zio.aws.honeycode.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.honeycode.model.primitives.{RowId, BatchItemId, WorkbookCursor}
import scala.jdk.CollectionConverters.*
final case class BatchCreateTableRowsResponse(
    workbookCursor: WorkbookCursor,
    createdRows: Map[BatchItemId, RowId],
    failedBatchItems: Option[
      Iterable[zio.aws.honeycode.model.FailedBatchItem]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse = {
    import BatchCreateTableRowsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
      .builder()
      .workbookCursor(WorkbookCursor.unwrap(workbookCursor): java.lang.Long)
      .createdRows(
        createdRows
          .map({ case (key, value) =>
            (BatchItemId.unwrap(key): java.lang.String) -> (RowId
              .unwrap(value): java.lang.String)
          })
          .asJava
      )
      .optionallyWith(
        failedBatchItems.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedBatchItems)
      .build()
  }
  def asReadOnly
      : zio.aws.honeycode.model.BatchCreateTableRowsResponse.ReadOnly =
    zio.aws.honeycode.model.BatchCreateTableRowsResponse.wrap(buildAwsValue())
}
object BatchCreateTableRowsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.honeycode.model.BatchCreateTableRowsResponse =
      zio.aws.honeycode.model.BatchCreateTableRowsResponse(
        workbookCursor,
        createdRows,
        failedBatchItems.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def workbookCursor: WorkbookCursor
    def createdRows: Map[BatchItemId, RowId]
    def failedBatchItems
        : Option[List[zio.aws.honeycode.model.FailedBatchItem.ReadOnly]]
    def getWorkbookCursor: ZIO[Any, Nothing, WorkbookCursor] =
      ZIO.succeed(workbookCursor)
    def getCreatedRows: ZIO[Any, Nothing, Map[BatchItemId, RowId]] =
      ZIO.succeed(createdRows)
    def getFailedBatchItems: ZIO[Any, AwsError, List[
      zio.aws.honeycode.model.FailedBatchItem.ReadOnly
    ]] = AwsError.unwrapOptionField("failedBatchItems", failedBatchItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
  ) extends zio.aws.honeycode.model.BatchCreateTableRowsResponse.ReadOnly {
    override val workbookCursor: WorkbookCursor =
      zio.aws.honeycode.model.primitives.WorkbookCursor(impl.workbookCursor())
    override val createdRows: Map[BatchItemId, RowId] = impl
      .createdRows()
      .asScala
      .map({ case (key, value) =>
        zio.aws.honeycode.model.primitives
          .BatchItemId(key) -> zio.aws.honeycode.model.primitives.RowId(value)
      })
      .toMap
    override val failedBatchItems
        : Option[List[zio.aws.honeycode.model.FailedBatchItem.ReadOnly]] = scala
      .Option(impl.failedBatchItems())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.honeycode.model.FailedBatchItem.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
  ): zio.aws.honeycode.model.BatchCreateTableRowsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-honeycode_3-5.17.271.1-sources.jar: zio/aws/honeycode/model/BatchCreateTableRowsResponse.scala <==
package zio.aws.honeycode.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.honeycode.model.primitives.{RowId, BatchItemId, WorkbookCursor}
import scala.jdk.CollectionConverters.*
final case class BatchCreateTableRowsResponse(
    workbookCursor: WorkbookCursor,
    createdRows: Map[BatchItemId, RowId],
    failedBatchItems: Optional[
      Iterable[zio.aws.honeycode.model.FailedBatchItem]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse = {
    import BatchCreateTableRowsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
      .builder()
      .workbookCursor(WorkbookCursor.unwrap(workbookCursor): java.lang.Long)
      .createdRows(
        createdRows
          .map({ case (key, value) =>
            (BatchItemId.unwrap(key): java.lang.String) -> (RowId
              .unwrap(value): java.lang.String)
          })
          .asJava
      )
      .optionallyWith(
        failedBatchItems.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedBatchItems)
      .build()
  }
  def asReadOnly
      : zio.aws.honeycode.model.BatchCreateTableRowsResponse.ReadOnly =
    zio.aws.honeycode.model.BatchCreateTableRowsResponse.wrap(buildAwsValue())
}
object BatchCreateTableRowsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.honeycode.model.BatchCreateTableRowsResponse =
      zio.aws.honeycode.model.BatchCreateTableRowsResponse(
        workbookCursor,
        createdRows,
        failedBatchItems.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def workbookCursor: WorkbookCursor
    def createdRows: Map[BatchItemId, RowId]
    def failedBatchItems
        : Optional[List[zio.aws.honeycode.model.FailedBatchItem.ReadOnly]]
    def getWorkbookCursor: ZIO[Any, Nothing, WorkbookCursor] =
      ZIO.succeed(workbookCursor)
    def getCreatedRows: ZIO[Any, Nothing, Map[BatchItemId, RowId]] =
      ZIO.succeed(createdRows)
    def getFailedBatchItems: ZIO[Any, AwsError, List[
      zio.aws.honeycode.model.FailedBatchItem.ReadOnly
    ]] = AwsError.unwrapOptionField("failedBatchItems", failedBatchItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
  ) extends zio.aws.honeycode.model.BatchCreateTableRowsResponse.ReadOnly {
    override val workbookCursor: WorkbookCursor =
      zio.aws.honeycode.model.primitives.WorkbookCursor(impl.workbookCursor())
    override val createdRows: Map[BatchItemId, RowId] = impl
      .createdRows()
      .asScala
      .map({ case (key, value) =>
        zio.aws.honeycode.model.primitives
          .BatchItemId(key) -> zio.aws.honeycode.model.primitives.RowId(value)
      })
      .toMap
    override val failedBatchItems
        : Optional[List[zio.aws.honeycode.model.FailedBatchItem.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.failedBatchItems())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.honeycode.model.FailedBatchItem.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.honeycode.model.BatchCreateTableRowsResponse
  ): zio.aws.honeycode.model.BatchCreateTableRowsResponse.ReadOnly =
    new Wrapper(impl)
}
